// ardrone_usbjoystick
// This sketch shows how to use a USB joystick to control your AR.Drone.
// Sigh: note special actions required to allow WiShield and USB Host Shield to be used at the same time:
// see the USBJoystick documentation for details.
// Sketch size about 24000
// mikem@airspayce.com
#include <WiShield.h>
#include <Ardrone.h>
#include <Usb.h>
#include <USBJoystick.h>

// Declare the ARDrone controller object
Ardrone ardrone;
// You must alter this to agree with the SSID of your AR.Drone. Use a WiFi client to find 
// out the SSID of your AR.Drone ad-hoc WiFi network.
const prog_char ssid[] PROGMEM = "ardrone_165416";

// Our singleton joystick
USBJoystick joy;

// Catch each button 1 press to toggle the flying state
// Catch each button 2 press to flash LEDS
// Catch each button 3 press to do a yaw shake animation
// button will be one of USBJOYSTICK_BUTTON_*
void buttonValueDidChangeCallback(uint8_t button, uint8_t value)
{
  if (button == USBJOYSTICK_BUTTON_1 && value)
    ardrone.setFlying(!ardrone.flying()); // Toggle flying state
  if (button == USBJOYSTICK_BUTTON_2 && value)
    ardrone.addAtLedCmd();            // Do the default LED Animation
  if (button == USBJOYSTICK_BUTTON_3 && value)
    ardrone.addAtAnimCmd(Ardrone::ARDRONE_ANIMATION_YAW_SHAKE);
}

void setup()
{
  Serial.begin(9600);

  ardrone.init();
  // Dont introduce any delays here until the connection to the Ardrone is established
  joy.setButtonValueDidChangeCallback(buttonValueDidChangeCallback);
  joy.init();
}

void loop()
{
  ardrone.run();
  joy.run();

  // Get latest joystick values and use them to set Ardrone flight parameters
  ardrone.setRoll (((float)joy.stickValue(USBJOYSTICK_STICK_RIGHT_HORIZ) - 128.0) / 128.0);
  ardrone.setPitch(((float)joy.stickValue(USBJOYSTICK_STICK_RIGHT_VERT)  - 128.0) / 128.0);
  ardrone.setGaz  (((float)joy.stickValue(USBJOYSTICK_STICK_LEFT_VERT)   - 128.0) / -128.0);
  ardrone.setYaw  (((float)joy.stickValue(USBJOYSTICK_STICK_LEFT_HORIZ)  - 128.0) / 128.0);
}


